@@ -14,33 +14,34 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Code';
 
-our $VERSION = '0.59'; # VERSION
+our $VERSION = '0.60'; # VERSION
 
 method new ($class: @args) {
 
-    my $arg  = $args[0];
-    my $role = 'Data::Object::Role::Type';
+  my $arg  = $args[0];
+  my $role = 'Data::Object::Role::Type';
 
-    $arg = $arg->data if Scalar::Util::blessed($arg)
-        and $arg->can('does')
-        and $arg->does($role);
+  $arg = $arg->data
+    if Scalar::Util::blessed($arg)
+    and $arg->can('does')
+    and $arg->does($role);
 
-    Data::Object::throw('Type Instantiation Error: Not a CodeRef')
-        unless 'CODE' eq ref $arg;
+  Data::Object::throw('Type Instantiation Error: Not a CodeRef')
+    unless 'CODE' eq ref $arg;
 
-    return bless $arg, $class;
+  return bless $arg, $class;
 
 }
 
-our @METHODS = @{ __PACKAGE__->methods };
+our @METHODS = @{__PACKAGE__->methods};
 
-my  $exclude = qr/^data|detract|new$/;
+my $exclude = qr/^data|detract|new$/;
 
-around [ grep { !/$exclude/ } @METHODS ] => fun ($orig, $self, @args) {
+around [grep { !/$exclude/ } @METHODS] => fun($orig, $self, @args) {
 
-    my $results = $self->$orig(@args);
+  my $results = $self->$orig(@args);
 
-    return Data::Object::deduce_deep($results);
+  return Data::Object::deduce_deep($results);
 
 };
 
@@ -58,13 +59,13 @@ Data::Object::Code - Code Object for Perl 5
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
-    use Data::Object::Code;
+  use Data::Object::Code;
 
-    my $code = Data::Object::Code->new(sub { shift + 1 });
+  my $code = Data::Object::Code->new(sub { shift + 1 });
 
 =head1 DESCRIPTION
 
@@ -84,19 +85,19 @@ supply a callback to the method called. A codified string can access its
 arguments by using variable names which correspond to letters in the alphabet
 which represent the position in the argument list. For example:
 
-    $code->example('$a + $b * $c', 100);
+  $code->example('$a + $b * $c', 100);
 
-    # if the example method does not supply any arguments automatically then
-    # the variable $a would be assigned the user-supplied value of 100,
-    # however, if the example method supplies two arguments automatically then
-    # those arugments would be assigned to the variables $a and $b whereas $c
-    # would be assigned the user-supplied value of 100
+  # if the example method does not supply any arguments automatically then
+  # the variable $a would be assigned the user-supplied value of 100,
+  # however, if the example method supplies two arguments automatically then
+  # those arugments would be assigned to the variables $a and $b whereas $c
+  # would be assigned the user-supplied value of 100
 
-    # e.g.
+  # e.g.
 
-    $code->conjoin('$code->(123)');
+  $code->conjoin('$code->(123)');
 
-    # etc
+  # etc
 
 Any place a codified string is accepted, a coderef or L<Data::Object::Code>
 object is also valid. Arguments are passed through the usual C<@_> list.
@@ -105,27 +106,27 @@ object is also valid. Arguments are passed through the usual C<@_> list.
 
 =head2 call
 
-    # given sub { (shift // 0) + 1 }
+  # given sub { (shift // 0) + 1 }
 
-    $code->call; # 1
-    $code->call(0); # 1
-    $code->call(1); # 2
-    $code->call(2); # 3
+  $code->call; # 1
+  $code->call(0); # 1
+  $code->call(1); # 2
+  $code->call(2); # 3
 
 The call method executes and returns the result of the code. This method returns
 a data type object to be determined after execution.
 
 =head2 compose
 
-    # given sub { [@_] }
+  # given sub { [@_] }
 
-    $code = $code->compose($code, 1,2,3);
-    $code->(4,5,6); # [[1,2,3,4,5,6]]
+  $code = $code->compose($code, 1,2,3);
+  $code->(4,5,6); # [[1,2,3,4,5,6]]
 
-    # this can be confusing, here's what's really happening:
-    my $listing = sub {[@_]}; # produces an arrayref of args
-    $listing->($listing->(@args)); # produces a listing within a listing
-    [[@args]] # the result
+  # this can be confusing, here's what's really happening:
+  my $listing = sub {[@_]}; # produces an arrayref of args
+  $listing->($listing->(@args)); # produces a listing within a listing
+  [[@args]] # the result
 
 The compose method creates a code reference which executes the first argument
 (another code reference) using the result from executing the code as it's
@@ -135,14 +136,14 @@ L<Data::Object::Code> object.
 
 =head2 conjoin
 
-    # given sub { $_[0] % 2 }
+  # given sub { $_[0] % 2 }
 
-    $code = $code->conjoin(sub { 1 });
-    $code->(0); # 0
-    $code->(1); # 1
-    $code->(2); # 0
-    $code->(3); # 1
-    $code->(4); # 0
+  $code = $code->conjoin(sub { 1 });
+  $code->(0); # 0
+  $code->(1); # 1
+  $code->(2); # 0
+  $code->(3); # 1
+  $code->(4); # 0
 
 The conjoin method creates a code reference which execute the code and the
 argument in a logical AND operation having the code as the lvalue and the
@@ -150,10 +151,10 @@ argument as the rvalue. This method returns a L<Data::Object::Code> object.
 
 =head2 curry
 
-    # given sub { [@_] }
+  # given sub { [@_] }
 
-    $code = $code->curry(1,2,3);
-    $code->(4,5,6); # [1,2,3,4,5,6]
+  $code = $code->curry(1,2,3);
+  $code->(4,5,6); # [1,2,3,4,5,6]
 
 The curry method returns a code reference which executes the code passing it
 the arguments and any additional parameters when executed. This method returns a
@@ -161,18 +162,18 @@ L<Data::Object::Code> object.
 
 =head2 data
 
-    # given $code
+  # given $code
 
-    $code->data; # original value
+  $code->data; # original value
 
 The data method returns the original and underlying value contained by the
 object. This method is an alias to the detract method.
 
 =head2 defined
 
-    # given $code
+  # given $code
 
-    $code->defined; # 1
+  $code->defined; # 1
 
 The defined method returns true if the object represents a value that meets the
 criteria for being defined, otherwise it returns false. This method returns a
@@ -180,23 +181,23 @@ L<Data::Object::Number> object.
 
 =head2 detract
 
-    # given $code
+  # given $code
 
-    $code->detract; # original value
+  $code->detract; # original value
 
 The detract method returns the original and underlying value contained by the
 object.
 
 =head2 disjoin
 
-    # given sub { $_[0] % 2 }
+  # given sub { $_[0] % 2 }
 
-    $code = $code->disjoin(sub { -1 });
-    $code->(0); # -1
-    $code->(1); #  1
-    $code->(2); # -1
-    $code->(3); #  1
-    $code->(4); # -1
+  $code = $code->disjoin(sub { -1 });
+  $code->(0); # -1
+  $code->(1); #  1
+  $code->(2); # -1
+  $code->(3); #  1
+  $code->(4); # -1
 
 The disjoin method creates a code reference which execute the code and the
 argument in a logical OR operation having the code as the lvalue and the
@@ -204,33 +205,33 @@ argument as the rvalue. This method returns a L<Data::Object::Code> object.
 
 =head2 dump
 
-    # given $code
+  # given $code
 
-    $code->dump; # sub { package Data::Object; goto \\&{\$data}; }
+  $code->dump; # sub { package Data::Object; goto \\&{\$data}; }
 
 The dump method returns returns a string representation of the object.
 This method returns a L<Data::Object::String> object.
 
 =head2 methods
 
-    # given $code
+  # given $code
 
-    $code->methods;
+  $code->methods;
 
 The methods method returns the list of methods attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 new
 
-    # given sub { shift + 1 }
+  # given sub { shift + 1 }
 
-    my $code = Data::Object::Code->new(sub { shift + 1 });
+  my $code = Data::Object::Code->new(sub { shift + 1 });
 
 The new method expects a code reference and returns a new class instance.
 
 =head2 next
 
-    $code->next;
+  $code->next;
 
 The next method is an alias to the call method. The naming is especially useful
 (i.e. helps with readability) when used with closure-based iterators. This
@@ -239,10 +240,10 @@ call method.
 
 =head2 rcurry
 
-    # given sub { [@_] }
+  # given sub { [@_] }
 
-    $code = $code->rcurry(1,2,3);
-    $code->(4,5,6); # [4,5,6,1,2,3]
+  $code = $code->rcurry(1,2,3);
+  $code->(4,5,6); # [4,5,6,1,2,3]
 
 The rcurry method returns a code reference which executes the code passing it
 the any additional parameters and any arguments when executed. This method
@@ -250,18 +251,18 @@ returns a L<Data::Object::Code> object.
 
 =head2 roles
 
-    # given $code
+  # given $code
 
-    $code->roles;
+  $code->roles;
 
 The roles method returns the list of roles attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 throw
 
-    # given $code
+  # given $code
 
-    $code->throw;
+  $code->throw;
 
 The throw method terminates the program using the core die keyword, passing the
 object to the L<Data::Object::Exception> class as the named parameter C<object>.
@@ -269,9 +270,9 @@ If captured this method returns a L<Data::Object::Exception> object.
 
 =head2 type
 
-    # given $code
+  # given $code
 
-    $code->type; # CODE
+  $code->type; # CODE
 
 The type method returns a string representing the internal data type object name.
 This method returns a L<Data::Object::String> object.
@@ -400,7 +401,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Al Newkirk.
+This software is copyright (c) 2018 by Al Newkirk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
