@@ -14,35 +14,36 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Float';
 
-our $VERSION = '0.59'; # VERSION
+our $VERSION = '0.60'; # VERSION
 
 method new ($class: @args) {
 
-    my $arg  = $args[0];
-    my $role = 'Data::Object::Role::Type';
+  my $arg  = $args[0];
+  my $role = 'Data::Object::Role::Type';
 
-    $arg = $arg->data if Scalar::Util::blessed($arg)
-        and $arg->can('does')
-        and $arg->does($role);
+  $arg = $arg->data
+    if Scalar::Util::blessed($arg)
+    and $arg->can('does')
+    and $arg->does($role);
 
-    $arg =~ s/^\+//; # not keen on this but ...
+  $arg =~ s/^\+//;    # not keen on this but ...
 
-    Data::Object::throw('Type Instantiation Error: Not a Floating-Point Number')
-        unless defined($arg) && ! ref($arg) && Scalar::Util::looks_like_number($arg);
+  Data::Object::throw('Type Instantiation Error: Not a Floating-Point Number')
+    unless defined($arg) && !ref($arg) && Scalar::Util::looks_like_number($arg);
 
-    return bless \$arg, $class;
+  return bless \$arg, $class;
 
 }
 
-our @METHODS = @{ __PACKAGE__->methods };
+our @METHODS = @{__PACKAGE__->methods};
 
-my  $exclude = qr/^data|detract|new$/;
+my $exclude = qr/^data|detract|new$/;
 
-around [ grep { !/$exclude/ } @METHODS ] => fun ($orig, $self, @args) {
+around [grep { !/$exclude/ } @METHODS] => fun($orig, $self, @args) {
 
-    my $results = $self->$orig(@args);
+  my $results = $self->$orig(@args);
 
-    return Data::Object::deduce_deep($results);
+  return Data::Object::deduce_deep($results);
 
 };
 
@@ -60,13 +61,13 @@ Data::Object::Float - Float Object for Perl 5
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
-    use Data::Object::Float;
+  use Data::Object::Float;
 
-    my $float = Data::Object::Float->new(9.9999);
+  my $float = Data::Object::Float->new(9.9999);
 
 =head1 DESCRIPTION
 
@@ -88,18 +89,18 @@ role and implements proxy methods as documented herewith.
 
 =head2 data
 
-    # given $float
+  # given $float
 
-    $float->data; # original value
+  $float->data; # original value
 
 The data method returns the original and underlying value contained by the
 object. This method is an alias to the detract method.
 
 =head2 defined
 
-    # given $float
+  # given $float
 
-    $float->defined; # 1
+  $float->defined; # 1
 
 The defined method returns true if the object represents a value that meets the
 criteria for being defined, otherwise it returns false. This method returns a
@@ -107,18 +108,18 @@ L<Data::Object::Number> object.
 
 =head2 detract
 
-    # given $float
+  # given $float
 
-    $float->detract; # original value
+  $float->detract; # original value
 
 The detract method returns the original and underlying value contained by the
 object.
 
 =head2 downto
 
-    # given 1.23
+  # given 1.23
 
-    $float->downto(0); # [1,0]
+  $float->downto(0); # [1,0]
 
 The downto method returns an array reference containing integer decreasing
 values down to and including the limit. This method returns a
@@ -126,27 +127,27 @@ L<Data::Object::Array> object.
 
 =head2 dump
 
-    # given 1.23
+  # given 1.23
 
-    $float->dump; # '1.23'
+  $float->dump; # '1.23'
 
 The dump method returns returns a string representation of the object.
 This method returns a L<Data::Object::String> object.
 
 =head2 eq
 
-    # given 1.23
+  # given 1.23
 
-    $float->eq(1); # 0
+  $float->eq(1); # 0
 
 The eq method performs a numeric equality operation. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 ge
 
-    # given 1.23
+  # given 1.23
 
-    $float->ge(1); # 1
+  $float->ge(1); # 1
 
 The ge method returns true if the argument provided is greater-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
@@ -154,18 +155,18 @@ object.
 
 =head2 gt
 
-    # given 1.23
+  # given 1.23
 
-    $float->gt(1); # 1
+  $float->gt(1); # 1
 
 The gt method performs a numeric greater-than comparison. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 le
 
-    # given 1.23
+  # given 1.23
 
-    $float->le(1); # 0
+  $float->le(1); # 0
 
 The le method returns true if the argument provided is less-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
@@ -173,62 +174,62 @@ object.
 
 =head2 lt
 
-    # given 1.23
+  # given 1.23
 
-    $float->lt(1.24); # 1
+  $float->lt(1.24); # 1
 
 The lt method performs a numeric less-than comparison. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 methods
 
-    # given $float
+  # given $float
 
-    $float->methods;
+  $float->methods;
 
 The methods method returns the list of methods attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 ne
 
-    # given 1.23
+  # given 1.23
 
-    $float->ne(1); # 1
+  $float->ne(1); # 1
 
 The ne method performs a numeric equality operation. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 new
 
-    # given 9.9999
+  # given 9.9999
 
-    my $float = Data::Object::Float->new(9.9999);
+  my $float = Data::Object::Float->new(9.9999);
 
 The new method expects a floating-point number and returns a new class instance.
 
 =head2 print
 
-    # given 1.23
+  # given 1.23
 
-    $float->print; # '1.23'
+  $float->print; # '1.23'
 
 The print method outputs the value represented by the object to STDOUT and
 returns true. This method returns a L<Data::Object::Number> object.
 
 =head2 roles
 
-    # given $float
+  # given $float
 
-    $float->roles;
+  $float->roles;
 
 The roles method returns the list of roles attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 say
 
-    # given 1.23
+  # given 1.23
 
-    $float->say; # '1.23\n'
+  $float->say; # '1.23\n'
 
 The say method outputs the value represented by the object appended with a
 newline to STDOUT and returns true. This method returns a L<Data::Object::Number>
@@ -236,9 +237,9 @@ object.
 
 =head2 throw
 
-    # given $float
+  # given $float
 
-    $float->throw;
+  $float->throw;
 
 The throw method terminates the program using the core die keyword, passing the
 object to the L<Data::Object::Exception> class as the named parameter C<object>.
@@ -246,10 +247,10 @@ If captured this method returns a L<Data::Object::Exception> object.
 
 =head2 to
 
-    # given 1.23
+  # given 1.23
 
-    $float->to(2); # [1,2]
-    $float->to(0); # [1,0]
+  $float->to(2); # [1,2]
+  $float->to(0); # [1,0]
 
 The to method returns an array reference containing integer increasing or
 decreasing values to and including the limit in ascending or descending order
@@ -258,18 +259,18 @@ L<Data::Object::Array> object.
 
 =head2 type
 
-    # given $float
+  # given $float
 
-    $float->type; # FLOAT
+  $float->type; # FLOAT
 
 The type method returns a string representing the internal data type object name.
 This method returns a L<Data::Object::String> object.
 
 =head2 upto
 
-    # given 1.23
+  # given 1.23
 
-    $float->upto(2); # [1,2]
+  $float->upto(2); # [1,2]
 
 The upto method returns an array reference containing integer increasing
 values up to and including the limit. This method returns a
@@ -415,7 +416,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Al Newkirk.
+This software is copyright (c) 2018 by Al Newkirk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
