@@ -14,37 +14,38 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Integer';
 
-our $VERSION = '0.59'; # VERSION
+our $VERSION = '0.60'; # VERSION
 
 method new ($class: @args) {
 
-    my $arg  = $args[0];
-    my $role = 'Data::Object::Role::Type';
+  my $arg  = $args[0];
+  my $role = 'Data::Object::Role::Type';
 
-    $arg = $arg->data if Scalar::Util::blessed($arg)
-        and $arg->can('does')
-        and $arg->does($role);
+  $arg = $arg->data
+    if Scalar::Util::blessed($arg)
+    and $arg->can('does')
+    and $arg->does($role);
 
-    $arg =~ s/^\+//; # not keen on this but ...
+  $arg =~ s/^\+//;    # not keen on this but ...
 
-    Data::Object::throw('Type Instantiation Error: Not an Integer')
-        unless defined($arg) && !ref($arg) && Scalar::Util::looks_like_number($arg);
+  Data::Object::throw('Type Instantiation Error: Not an Integer')
+    unless defined($arg) && !ref($arg) && Scalar::Util::looks_like_number($arg);
 
-    $arg += 0 unless $arg =~ /[a-zA-Z]/;
+  $arg += 0 unless $arg =~ /[a-zA-Z]/;
 
-    return bless \$arg, $class;
+  return bless \$arg, $class;
 
 }
 
-our @METHODS = @{ __PACKAGE__->methods };
+our @METHODS = @{__PACKAGE__->methods};
 
-my  $exclude = qr/^data|detract|new$/;
+my $exclude = qr/^data|detract|new$/;
 
-around [ grep { !/$exclude/ } @METHODS ] => fun ($orig, $self, @args) {
+around [grep { !/$exclude/ } @METHODS] => fun($orig, $self, @args) {
 
-    my $results = $self->$orig(@args);
+  my $results = $self->$orig(@args);
 
-    return Data::Object::deduce_deep($results);
+  return Data::Object::deduce_deep($results);
 
 };
 
@@ -62,13 +63,13 @@ Data::Object::Integer - Integer Object for Perl 5
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
-    use Data::Object::Integer;
+  use Data::Object::Integer;
 
-    my $integer = Data::Object::Integer->new(9);
+  my $integer = Data::Object::Integer->new(9);
 
 =head1 DESCRIPTION
 
@@ -89,18 +90,18 @@ role and implements proxy methods as documented herewith.
 
 =head2 data
 
-    # given $integer
+  # given $integer
 
-    $integer->data; # original value
+  $integer->data; # original value
 
 The data method returns the original and underlying value contained by the
 object. This method is an alias to the detract method.
 
 =head2 defined
 
-    # given $integer
+  # given $integer
 
-    $integer->defined; # 1
+  $integer->defined; # 1
 
 The defined method returns true if the object represents a value that meets the
 criteria for being defined, otherwise it returns false. This method returns a
@@ -108,18 +109,18 @@ L<Data::Object::Number> object.
 
 =head2 detract
 
-    # given $integer
+  # given $integer
 
-    $integer->detract; # original value
+  $integer->detract; # original value
 
 The detract method returns the original and underlying value contained by the
 object.
 
 =head2 downto
 
-    # given 1
+  # given 1
 
-    $integer->downto(0); # [1,0]
+  $integer->downto(0); # [1,0]
 
 The downto method returns an array reference containing integer decreasing
 values down to and including the limit. This method returns a
@@ -127,27 +128,27 @@ L<Data::Object::Array> object.
 
 =head2 dump
 
-    # given 1
+  # given 1
 
-    $integer->dump; # '1'
+  $integer->dump; # '1'
 
 The dump method returns returns a string representation of the object.
 This method returns a L<Data::Object::String> object.
 
 =head2 eq
 
-    # given 1
+  # given 1
 
-    $integer->eq(1); # 1
+  $integer->eq(1); # 1
 
 The eq method performs a numeric equality operation. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 ge
 
-    # given 1
+  # given 1
 
-    $integer->ge(0); # 1
+  $integer->ge(0); # 1
 
 The ge method returns true if the argument provided is greater-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
@@ -155,18 +156,18 @@ object.
 
 =head2 gt
 
-    # given 1
+  # given 1
 
-    $integer->gt(1); # 0
+  $integer->gt(1); # 0
 
 The gt method performs a numeric greater-than comparison. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 le
 
-    # given 0
+  # given 0
 
-    $integer->le(1); # 1
+  $integer->le(1); # 1
 
 The le method returns true if the argument provided is less-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
@@ -174,62 +175,62 @@ object.
 
 =head2 lt
 
-    # given 1
+  # given 1
 
-    $integer->lt(1); # 0
+  $integer->lt(1); # 0
 
 The lt method performs a numeric less-than comparison. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 methods
 
-    # given $integer
+  # given $integer
 
-    $integer->methods;
+  $integer->methods;
 
 The methods method returns the list of methods attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 ne
 
-    # given 1
+  # given 1
 
-    $integer->ne(0); # 1
+  $integer->ne(0); # 1
 
 The ne method performs a numeric equality operation. This method returns a
 L<Data::Object::Number> object representing a boolean.
 
 =head2 new
 
-    # given 9
+  # given 9
 
-    my $integer = Data::Object::Integer->new(9);
+  my $integer = Data::Object::Integer->new(9);
 
 The new method expects a number and returns a new class instance.
 
 =head2 print
 
-    # given 0
+  # given 0
 
-    $integer->print; # '0'
+  $integer->print; # '0'
 
 The print method outputs the value represented by the object to STDOUT and
 returns true. This method returns a L<Data::Object::Number> object.
 
 =head2 roles
 
-    # given $integer
+  # given $integer
 
-    $integer->roles;
+  $integer->roles;
 
 The roles method returns the list of roles attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 say
 
-    # given 0
+  # given 0
 
-    $integer->say; # '0\n'
+  $integer->say; # '0\n'
 
 The say method outputs the value represented by the object appended with a
 newline to STDOUT and returns true. This method returns a L<Data::Object::Number>
@@ -237,9 +238,9 @@ object.
 
 =head2 throw
 
-    # given $integer
+  # given $integer
 
-    $integer->throw;
+  $integer->throw;
 
 The throw method terminates the program using the core die keyword, passing the
 object to the L<Data::Object::Exception> class as the named parameter C<object>.
@@ -247,10 +248,10 @@ If captured this method returns a L<Data::Object::Exception> object.
 
 =head2 to
 
-    # given 1
+  # given 1
 
-    $integer->to(2); # [1,2]
-    $integer->to(0); # [1,0]
+  $integer->to(2); # [1,2]
+  $integer->to(0); # [1,0]
 
 The to method returns an array reference containing integer increasing or
 decreasing values to and including the limit in ascending or descending order
@@ -259,18 +260,18 @@ L<Data::Object::Array> object.
 
 =head2 type
 
-    # given $integer
+  # given $integer
 
-    $integer->type; # INTEGER
+  $integer->type; # INTEGER
 
 The type method returns a string representing the internal data type object name.
 This method returns a L<Data::Object::String> object.
 
 =head2 upto
 
-    # given 1
+  # given 1
 
-    $integer->upto(2); # [1,2]
+  $integer->upto(2); # [1,2]
 
 The upto method returns an array reference containing integer increasing
 values up to and including the limit. This method returns a
@@ -416,7 +417,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Al Newkirk.
+This software is copyright (c) 2018 by Al Newkirk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
