@@ -13,524 +13,513 @@ use Data::Object::Signatures;
 use Scalar::Util;
 
 map with($_), our @ROLES = qw(
-    Data::Object::Role::Collection
-    Data::Object::Role::Item
+  Data::Object::Role::Collection
+  Data::Object::Role::Item
 );
 
-our $VERSION = '0.59'; # VERSION
+our $VERSION = '0.60'; # VERSION
 
 method clear () {
 
-    return $self->empty;
+  return $self->empty;
 
 }
 
 method count () {
 
-    return $self->length;
+  return $self->length;
 
 }
 
 method defined ($key) {
 
-    return CORE::defined($self->{$key});
+  return CORE::defined($self->{$key});
 
 }
 
 method delete ($key) {
 
-    return CORE::delete($self->{$key});
+  return CORE::delete($self->{$key});
 
 }
 
 method each ($code, @args) {
 
-    for my $key (CORE::keys %$self) {
+  for my $key (CORE::keys %$self) {
 
-        my $value = $self->{$key};
+    my $value = $self->{$key};
 
-        my $refs = {
-            '$key'   => \$key,
-            '$value' => \$value,
-        };
+    my $refs = {'$key' => \$key, '$value' => \$value,};
 
-        Data::Object::codify($code, $refs)->($key, $value, @args);
+    Data::Object::codify($code, $refs)->($key, $value, @args);
 
-    }
+  }
 
-    return $self;
+  return $self;
 
 }
 
 method each_key ($code, @args) {
 
-    for my $key (CORE::keys %$self) {
+  for my $key (CORE::keys %$self) {
 
-        my $value = $self->{$key};
+    my $value = $self->{$key};
 
-        my $refs = {
-            '$key'   => \$key,
-            '$value' => \$value,
-        };
+    my $refs = {'$key' => \$key, '$value' => \$value,};
 
-        Data::Object::codify($code, $refs)->($key, @args);
+    Data::Object::codify($code, $refs)->($key, @args);
 
-    }
+  }
 
-    return $self;
+  return $self;
 
 }
 
 method each_n_values ($number, $code, @args) {
 
-    my $refs = {};
-    my @list = CORE::keys %$self;
+  my $refs = {};
+  my @list = CORE::keys %$self;
 
-    while (my @keys = CORE::splice(@list, 0, $number)) {
+  while (my @keys = CORE::splice(@list, 0, $number)) {
 
-        my @values;
+    my @values;
 
-        for (my $i = 0; $i < @keys; $i++) {
+    for (my $i = 0; $i < @keys; $i++) {
 
-            my $pos   = $i;
-            my $key   = $keys[$pos];
-            my $value = CORE::defined($key) ? $self->{$key} : undef;
+      my $pos   = $i;
+      my $key   = $keys[$pos];
+      my $value = CORE::defined($key) ? $self->{$key} : undef;
 
-            $refs->{"\$key${i}"}   = $key   if CORE::defined $key;
-            $refs->{"\$value${i}"} = $value if CORE::defined $value;
+      $refs->{"\$key${i}"}   = $key   if CORE::defined $key;
+      $refs->{"\$value${i}"} = $value if CORE::defined $value;
 
-            push @values, $value;
-
-        }
-
-        Data::Object::codify($code, $refs)->(@values, @args);
+      push @values, $value;
 
     }
 
-    return $self;
+    Data::Object::codify($code, $refs)->(@values, @args);
+
+  }
+
+  return $self;
 
 }
 
 method each_value ($code, @args) {
 
-    for my $key (CORE::keys %$self) {
+  for my $key (CORE::keys %$self) {
 
-        my $value = $self->{$key};
+    my $value = $self->{$key};
 
-        my $refs = {
-            '$key'   => \$key,
-            '$value' => \$value,
-        };
+    my $refs = {'$key' => \$key, '$value' => \$value,};
 
-        Data::Object::codify($code, $refs)->($value, @args);
+    Data::Object::codify($code, $refs)->($value, @args);
 
-    }
+  }
 
-    return $self;
+  return $self;
 
 }
 
 method empty () {
 
-    CORE::delete @$self{CORE::keys %$self};
+  CORE::delete @$self{CORE::keys %$self};
 
-    return $self;
+  return $self;
 
 }
 
-method eq {
+method eq () {
 
-    $self->throw("the eq() comparison operation is not supported");
+  $self->throw("the eq() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method exists ($key) {
 
-    return CORE::exists $self->{$key};
+  return CORE::exists $self->{$key};
 
 }
 
 method filter_exclude (@args) {
 
-    my %i = map { $_ => $_ } @args;
+  my %i = map { $_ => $_ } @args;
 
-    return {
+  return {
 
-        CORE::map  { CORE::exists($self->{$_}) ? ($_ => $self->{$_}) : () }
+    CORE::map { CORE::exists($self->{$_}) ? ($_ => $self->{$_}) : () }
 
-        CORE::grep { not CORE::exists($i{$_}) } CORE::keys %$self
+      CORE::grep { not CORE::exists($i{$_}) } CORE::keys %$self
 
-    };
+  };
 
 }
 
 method filter_include (@args) {
 
-    return {
+  return {
 
-        CORE::map { CORE::exists($self->{$_}) ? ($_ => $self->{$_}) : () }
+    CORE::map { CORE::exists($self->{$_}) ? ($_ => $self->{$_}) : () }
 
-        @args
+      @args
 
-    };
+  };
 
 }
 
 method fold ($path, $store, $cache) {
 
-    $store ||= {};
-    $cache ||= {};
+  $store ||= {};
+  $cache ||= {};
 
-    my $ref = CORE::ref($self);
-    my $obj = Scalar::Util::blessed($self);
-    my $adr = Scalar::Util::refaddr($self);
-    my $tmp = { %$cache };
+  my $ref = CORE::ref($self);
+  my $obj = Scalar::Util::blessed($self);
+  my $adr = Scalar::Util::refaddr($self);
+  my $tmp = {%$cache};
 
-    if ($adr && $tmp->{$adr}) {
+  if ($adr && $tmp->{$adr}) {
 
-        $store->{$path} = $self;
+    $store->{$path} = $self;
 
-    } elsif ($ref eq 'HASH'  || ($obj and $obj->isa('Data::Object::Hash'))) {
+  }
+  elsif ($ref eq 'HASH' || ($obj and $obj->isa('Data::Object::Hash'))) {
 
-        $tmp->{$adr} = 1;
+    $tmp->{$adr} = 1;
 
-        if (%$self) {
+    if (%$self) {
 
-            for my $key (CORE::sort(CORE::keys %$self)) {
+      for my $key (CORE::sort(CORE::keys %$self)) {
 
-                my $place = $path ? CORE::join('.', $path, $key) : $key;
-                my $value = $self->{$key};
+        my $place = $path ? CORE::join('.', $path, $key) : $key;
+        my $value = $self->{$key};
 
-                fold($value, $place, $store, $tmp);
+        fold($value, $place, $store, $tmp);
 
-            }
+      }
 
-        } else {
+    }
+    else {
 
-            $store->{$path} = {};
-
-        }
-
-    } elsif ($ref eq 'ARRAY' || ($obj and $obj->isa('Data::Object::Array'))) {
-
-        $tmp->{$adr} = 1;
-
-        if (@$self) {
-
-            for my $idx (0 .. $#$self) {
-
-                my $place = $path ? CORE::join(':', $path, $idx) : $idx;
-                my $value = $self->[$idx];
-
-                fold($value, $place, $store, $tmp);
-
-            }
-
-        } else {
-
-            $store->{$path} = [];
-
-        }
-
-    } else {
-
-        $store->{$path} = $self if $path;
+      $store->{$path} = {};
 
     }
 
-    return $store;
+  }
+  elsif ($ref eq 'ARRAY' || ($obj and $obj->isa('Data::Object::Array'))) {
+
+    $tmp->{$adr} = 1;
+
+    if (@$self) {
+
+      for my $idx (0 .. $#$self) {
+
+        my $place = $path ? CORE::join(':', $path, $idx) : $idx;
+        my $value = $self->[$idx];
+
+        fold($value, $place, $store, $tmp);
+
+      }
+
+    }
+    else {
+
+      $store->{$path} = [];
+
+    }
+
+  }
+  else {
+
+    $store->{$path} = $self if $path;
+
+  }
+
+  return $store;
 
 }
 
-method ge {
+method ge () {
 
-    $self->throw("the ge() comparison operation is not supported");
+  $self->throw("the ge() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method get ($key) {
 
-    return $self->{$key};
+  return $self->{$key};
 
 }
 
 method grep ($code, @args) {
 
-    my @caught;
+  my @caught;
 
-    for my $key (CORE::keys %$self) {
+  for my $key (CORE::keys %$self) {
 
-        my $value = $self->{$key};
+    my $value = $self->{$key};
 
-        my $refs = {
-            '$key'   => \$key,
-            '$value' => \$value,
-        };
+    my $refs = {'$key' => \$key, '$value' => \$value,};
 
-        my $result = Data::Object::codify($code, $refs)->($value, @args);
+    my $result = Data::Object::codify($code, $refs)->($value, @args);
 
-        push @caught, $key, $value if $result;
+    push @caught, $key, $value if $result;
 
-    }
+  }
 
-    return { @caught };
+  return {@caught};
 
 }
 
-method gt {
+method gt () {
 
-    $self->throw("the gt() comparison operation is not supported");
+  $self->throw("the gt() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
-method head {
+method head () {
 
-    $self->throw("the gt() comparison operation is not supported");
+  $self->throw("the gt() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method invert () {
 
-    return $self->reverse;
+  return $self->reverse;
 
 }
 
 method iterator () {
 
-    my @keys = CORE::keys %{$self};
+  my @keys = CORE::keys %{$self};
 
-    my $i = 0;
+  my $i = 0;
 
-    return sub {
+  return sub {
 
-        return undef if $i > $#keys;
+    return undef if $i > $#keys;
 
-        return $self->{$keys[$i++]};
+    return $self->{$keys[$i++]};
 
-    }
+  }
 
 }
 
-method join {
+method join () {
 
-    $self->throw("the join() comparison operation is not supported");
+  $self->throw("the join() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method keys () {
 
-    return [ CORE::keys %$self ];
+  return [CORE::keys %$self];
 
 }
 
-method le {
+method le () {
 
-    $self->throw("the le() comparison operation is not supported");
+  $self->throw("the le() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method length () {
 
-    return scalar CORE::keys %$self;
+  return scalar CORE::keys %$self;
 
 }
 
 method list () {
 
-    return [ %$self ];
+  return [%$self];
 
 }
 
 method lookup ($path) {
 
-    return undef unless ($self and $path) and (
-        ('HASH' eq ref($self)) or Scalar::Util::blessed($self)
-            and $self->isa('HASH')
-    );
+  return undef
+    unless ($self and $path)
+    and (('HASH' eq ref($self))
+    or Scalar::Util::blessed($self) and $self->isa('HASH'));
 
-    return $self->{$path} if $self->{$path};
+  return $self->{$path} if $self->{$path};
 
-    my $next;
-    my $rest;
+  my $next;
+  my $rest;
 
-    ($next, $rest) = $path =~ /(.*)\.([^\.]+)$/;
-    return lookup($self->{$next}, $rest) if $next and $self->{$next};
+  ($next, $rest) = $path =~ /(.*)\.([^\.]+)$/;
+  return lookup($self->{$next}, $rest) if $next and $self->{$next};
 
-    ($next, $rest) = $path =~ /([^\.]+)\.(.*)$/;
-    return lookup($self->{$next}, $rest) if $next and $self->{$next};
+  ($next, $rest) = $path =~ /([^\.]+)\.(.*)$/;
+  return lookup($self->{$next}, $rest) if $next and $self->{$next};
 
-    return undef;
+  return undef;
 
 }
 
-method lt {
+method lt () {
 
-    $self->throw("the lt() comparison operation is not supported");
+  $self->throw("the lt() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method map ($code, @args) {
 
-    my @caught;
+  my @caught;
 
-    for my $key (CORE::keys %$self) {
+  for my $key (CORE::keys %$self) {
 
-        my $value = $self->{$key};
+    my $value = $self->{$key};
 
-        my $refs = {
-            '$key'   => \$key,
-            '$value' => \$value,
-        };
+    my $refs = {'$key' => \$key, '$value' => \$value,};
 
-        push @caught, (Data::Object::codify($code, $refs)->($key, @args));
+    push @caught, (Data::Object::codify($code, $refs)->($key, @args));
 
-    }
+  }
 
-    return [ @caught ];
+  return [@caught];
 
 }
 
 method merge (@args) {
 
-    require Storable;
+  require Storable;
 
-    return Storable::dclone($self) if ! @args;
-    return Storable::dclone(merge($self, merge(@args))) if @args > 1;
+  return Storable::dclone($self) if !@args;
+  return Storable::dclone(merge($self, merge(@args))) if @args > 1;
 
-    my ($right) = @args;
-    my (%merge) = %$self;
+  my ($right) = @args;
+  my (%merge) = %$self;
 
-    for my $key (CORE::keys %$right) {
+  for my $key (CORE::keys %$right) {
 
-        my $lprop = $$self{$key};
-        my $rprop = $$right{$key};
+    my $lprop = $$self{$key};
+    my $rprop = $$right{$key};
 
-        $merge{$key} = ((ref($rprop) eq 'HASH') and (ref($lprop) eq 'HASH'))
-            ? merge($$self{$key}, $$right{$key}) : $$right{$key};
+    $merge{$key}
+      = ((ref($rprop) eq 'HASH') and (ref($lprop) eq 'HASH'))
+      ? merge($$self{$key}, $$right{$key})
+      : $$right{$key};
 
-    }
+  }
 
-    return Storable::dclone(\%merge);
+  return Storable::dclone(\%merge);
 
 }
 
-method ne {
+method ne () {
 
-    $self->throw("the ne() comparison operation is not supported");
+  $self->throw("the ne() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method pairs () {
 
-    return [ CORE::map { [ $_, $self->{$_} ] } CORE::keys(%$self) ];
+  return [CORE::map { [$_, $self->{$_}] } CORE::keys(%$self)];
 
 }
 
 method reset () {
 
-    @$self{ CORE::keys( %$self ) } = ();
+  @$self{CORE::keys(%$self)} = ();
 
-    return $self;
+  return $self;
 
 }
 
-method reverse {
+method reverse () {
 
-    my $data = {};
+  my $data = {};
 
-    for (CORE::keys %$self) {
+  for (CORE::keys %$self) {
 
-        $data->{$_} = $self->{$_} if CORE::defined($self->{$_});
+    $data->{$_} = $self->{$_} if CORE::defined($self->{$_});
 
-    }
+  }
 
-    return { CORE::reverse %$data };
+  return {CORE::reverse %$data};
 
 }
 
 method set ($key, $value) {
 
-    return $self->{$key} = $value;
+  return $self->{$key} = $value;
 
 }
 
 method slice (@args) {
 
-    return { CORE::map { $_ => $self->{$_} } @args };
+  return {CORE::map { $_ => $self->{$_} } @args};
 
 }
 
-method sort {
+method sort () {
 
-    $self->throw("the sort() comparison operation is not supported");
+  $self->throw("the sort() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
-method tail {
+method tail () {
 
-    $self->throw("the tail() comparison operation is not supported");
+  $self->throw("the tail() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
 method unfold () {
 
-    my $store = {};
+  my $store = {};
 
-    for my $key (CORE::sort(CORE::keys(%$self))) {
+  for my $key (CORE::sort(CORE::keys(%$self))) {
 
-        my $node = $store;
-        my @steps = CORE::split(/\./, $key);
+    my $node  = $store;
+    my @steps = CORE::split(/\./, $key);
 
-        for (my $i=0; $i < @steps; $i++) {
+    for (my $i = 0; $i < @steps; $i++) {
 
-            my $last = $i == $#steps;
-            my $step = $steps[$i];
+      my $last = $i == $#steps;
+      my $step = $steps[$i];
 
-            if (my @parts = $step =~ /^(\w*):(0|[1-9]\d*)$/) {
-                $node = $node->{$parts[0]}[$parts[1]] = $last
-                    ? $self->{$key}
-                    : exists $node->{$parts[0]}[$parts[1]]
-                    ?        $node->{$parts[0]}[$parts[1]]
-                    : {};
-            } else {
-                $node = $node->{$step} = $last
-                    ? $self->{$key}
-                    : exists $node->{$step}
-                    ?        $node->{$step}
-                    : {};
-            }
-
-        }
+      if (my @parts = $step =~ /^(\w*):(0|[1-9]\d*)$/) {
+        $node = $node->{$parts[0]}[$parts[1]]
+          = $last                                ? $self->{$key}
+          : exists $node->{$parts[0]}[$parts[1]] ? $node->{$parts[0]}[$parts[1]]
+          :                                        {};
+      }
+      else {
+        $node = $node->{$step}
+          = $last ? $self->{$key} : exists $node->{$step} ? $node->{$step} : {};
+      }
 
     }
 
-    return $store;
+  }
+
+  return $store;
 
 }
 
 method values (@args) {
 
-    return [ @args ? @{$self}{@args} : CORE::values(%$self) ];
+  return [@args ? @{$self}{@args} : CORE::values(%$self)];
 
 }
 
@@ -548,13 +537,13 @@ Data::Object::Role::Hash - Hash Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
-    use Data::Object::Class;
+  use Data::Object::Class;
 
-    with 'Data::Object::Role::Hash';
+  with 'Data::Object::Role::Hash';
 
 =head1 DESCRIPTION
 
@@ -569,23 +558,23 @@ supply a callback to the method called. A codified string can access its
 arguments by using variable names which correspond to letters in the alphabet
 which represent the position in the argument list. For example:
 
-    $hash->example('$a + $b * $c', 100);
+  $hash->example('$a + $b * $c', 100);
 
-    # if the example method does not supply any arguments automatically then
-    # the variable $a would be assigned the user-supplied value of 100,
-    # however, if the example method supplies two arguments automatically then
-    # those arugments would be assigned to the variables $a and $b whereas $c
-    # would be assigned the user-supplied value of 100
+  # if the example method does not supply any arguments automatically then
+  # the variable $a would be assigned the user-supplied value of 100,
+  # however, if the example method supplies two arguments automatically then
+  # those arugments would be assigned to the variables $a and $b whereas $c
+  # would be assigned the user-supplied value of 100
 
-    # e.g.
+  # e.g.
 
-    $hash->each('the value at $key is $value');
+  $hash->each('the value at $key is $value');
 
-    # or
+  # or
 
-    $hash->each_n_values(4, 'the value at $key0 is $value0');
+  $hash->each_n_values(4, 'the value at $key0 is $value0');
 
-    # etc
+  # etc
 
 Any place a codified string is accepted, a coderef or L<Data::Object::Code>
 object is also valid. Arguments are passed through the usual C<@_> list.
@@ -594,38 +583,38 @@ object is also valid. Arguments are passed through the usual C<@_> list.
 
 =head2 clear
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->clear; # {}
+  $hash->clear; # {}
 
 The clear method is an alias to the empty method. This method returns a
 hash object. This method is an alias to the empty method.
 
 =head2 count
 
-    # given {1..4}
+  # given {1..4}
 
-    my $count = $hash->count; # 2
+  my $count = $hash->count; # 2
 
 The count method returns the total number of keys defined. This method returns
 a number object.
 
 =head2 data
 
-    # given $hash
+  # given $hash
 
-    $hash->data; # original value
+  $hash->data; # original value
 
 The data method returns the original and underlying value contained by the
 object. This method is an alias to the detract method.
 
 =head2 defined
 
-    # given {1..8,9,undef}
+  # given {1..8,9,undef}
 
-    $hash->defined(1); # 1; true
-    $hash->defined(0); # 0; false
-    $hash->defined(9); # 0; false
+  $hash->defined(1); # 1; true
+  $hash->defined(0); # 0; false
+  $hash->defined(9); # 0; false
 
 The defined method returns true if the value matching the key specified in the
 argument if defined, otherwise returns false. This method returns a
@@ -633,9 +622,9 @@ number object.
 
 =head2 delete
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->delete(1); # 2
+  $hash->delete(1); # 2
 
 The delete method returns the value matching the key specified in the argument
 and returns the value. This method returns a data type object to be determined
@@ -643,30 +632,30 @@ after execution.
 
 =head2 detract
 
-    # given $hash
+  # given $hash
 
-    $hash->detract; # original value
+  $hash->detract; # original value
 
 The detract method returns the original and underlying value contained by the
 object.
 
 =head2 dump
 
-    # given {1..4}
+  # given {1..4}
 
-    $hash->dump; # '{1=>2,3=>4}'
+  $hash->dump; # '{1=>2,3=>4}'
 
 The dump method returns returns a string representation of the object.
 This method returns a string value.
 
 =head2 each
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->each(sub{
-        my $key   = shift; # 1
-        my $value = shift; # 2
-    });
+  $hash->each(sub{
+    my $key   = shift; # 1
+    my $value = shift; # 2
+  });
 
 The each method iterates over each element in the hash, executing the code
 reference supplied in the argument, passing the routine the key and value at the
@@ -676,11 +665,11 @@ object. This method returns a hash value.
 
 =head2 each_key
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->each_key(sub{
-        my $key = shift; # 1
-    });
+  $hash->each_key(sub{
+    my $key = shift; # 1
+  });
 
 The each_key method iterates over each element in the hash, executing the code
 reference supplied in the argument, passing the routine the key at the current
@@ -690,15 +679,15 @@ This method returns a hash value.
 
 =head2 each_n_values
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->each_n_values(4, sub {
-        my $value_1 = shift; # 2
-        my $value_2 = shift; # 4
-        my $value_3 = shift; # 6
-        my $value_4 = shift; # 8
-        ...
-    });
+  $hash->each_n_values(4, sub {
+    my $value_1 = shift; # 2
+    my $value_2 = shift; # 4
+    my $value_3 = shift; # 6
+    my $value_4 = shift; # 8
+    ...
+  });
 
 The each_n_values method iterates over each element in the hash, executing the
 code reference supplied in the argument, passing the routine the next n values
@@ -708,11 +697,11 @@ type object. This method returns a hash value.
 
 =head2 each_value
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->each_value(sub {
-        my $value = shift; # 2
-    });
+  $hash->each_value(sub {
+    my $value = shift; # 2
+  });
 
 The each_value method iterates over each element in the hash, executing the code
 reference supplied in the argument, passing the routine the value at the current
@@ -722,28 +711,28 @@ This method returns a hash value.
 
 =head2 empty
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->empty; # {}
+  $hash->empty; # {}
 
 The empty method drops all elements from the hash. This method returns a
 hash object. Note: This method modifies the hash.
 
 =head2 eq
 
-    # given $hash
+  # given $hash
 
-    $hash->eq; # exception thrown
+  $hash->eq; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 exists
 
-    # given {1..8,9,undef}
+  # given {1..8,9,undef}
 
-    $hash->exists(1); # 1; true
-    $hash->exists(0); # 0; false
+  $hash->exists(1); # 1; true
+  $hash->exists(0); # 0; false
 
 The exists method returns true if the value matching the key specified in the
 argument exists, otherwise returns false. This method returns a
@@ -751,9 +740,9 @@ number object.
 
 =head2 filter_exclude
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->filter_exclude(1,3); # {5=>6,7=>8}
+  $hash->filter_exclude(1,3); # {5=>6,7=>8}
 
 The filter_exclude method returns a hash reference consisting of all key/value
 pairs in the hash except for the pairs whose keys are specified in the
@@ -761,9 +750,9 @@ arguments. This method returns a hash value.
 
 =head2 filter_include
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->filter_include(1,3); # {1=>2,3=>4}
+  $hash->filter_include(1,3); # {1=>2,3=>4}
 
 The filter_include method returns a hash reference consisting of only key/value
 pairs whose keys are specified in the arguments. This method returns a
@@ -771,9 +760,9 @@ hash object.
 
 =head2 fold
 
-    # given {3,[4,5,6],7,{8,8,9,9}}
+  # given {3,[4,5,6],7,{8,8,9,9}}
 
-    $hash->fold; # {'3:0'=>4,'3:1'=>5,'3:2'=>6,'7.8'=>8,'7.9'=>9}
+  $hash->fold; # {'3:0'=>4,'3:1'=>5,'3:2'=>6,'7.8'=>8,'7.9'=>9}
 
 The fold method returns a single-level hash reference consisting of key/value
 pairs whose keys are paths (using dot-notation where the segments correspond to
@@ -782,18 +771,18 @@ returns a hash value.
 
 =head2 ge
 
-    # given $hash
+  # given $hash
 
-    $hash->ge; # exception thrown
+  $hash->ge; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 get
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->get(5); # 6
+  $hash->get(5); # 6
 
 The get method returns the value of the element in the hash whose key
 corresponds to the key specified in the argument. This method returns a data
@@ -801,13 +790,13 @@ type object to be determined after execution.
 
 =head2 grep
 
-    # given {1..4}
+  # given {1..4}
 
-    $hash->grep(sub {
-        shift >= 3
-    });
+  $hash->grep(sub {
+    shift >= 3
+  });
 
-    # {3=>5}
+  # {3=>5}
 
 The grep method iterates over each key/value pair in the hash, executing the
 code reference supplied in the argument, passing the routine the key and value
@@ -819,27 +808,27 @@ hash object.
 
 =head2 gt
 
-    # given $hash
+  # given $hash
 
-    $hash->gt; # exception thrown
+  $hash->gt; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 head
 
-    # given $hash
+  # given $hash
 
-    $hash->head; # exception thrown
+  $hash->head; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 invert
 
-    # given {1..8,9,undef,10,''}
+  # given {1..8,9,undef,10,''}
 
-    $hash->invert; # {''=>10,2=>1,4=>3,6=>5,8=>7}
+  $hash->invert; # {''=>10,2=>1,4=>3,6=>5,8=>7}
 
 The invert method returns the hash after inverting the keys and values
 respectively. Note, keys with undefined values will be dropped, also, this
@@ -848,12 +837,12 @@ Note: This method modifies the hash.
 
 =head2 iterator
 
-    # given {1..8}
+  # given {1..8}
 
-    my $iterator = $hash->iterator;
-    while (my $value = $iterator->next) {
-        say $value; # 2
-    }
+  my $iterator = $hash->iterator;
+  while (my $value = $iterator->next) {
+    say $value; # 2
+  }
 
 The iterator method returns a code reference which can be used to iterate over
 the hash. Each time the iterator is executed it will return the values of the
@@ -863,56 +852,56 @@ code object.
 
 =head2 join
 
-    # given $hash
+  # given $hash
 
-    $hash->join; # exception thrown
+  $hash->join; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 keys
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->keys; # [1,3,5,7]
+  $hash->keys; # [1,3,5,7]
 
 The keys method returns an array reference consisting of all the keys in the
 hash. This method returns an array value.
 
 =head2 le
 
-    # given $hash
+  # given $hash
 
-    $hash->le; # exception thrown
+  $hash->le; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 length
 
-    # given {1..8}
+  # given {1..8}
 
-    my $length = $hash->length; # 4
+  my $length = $hash->length; # 4
 
 The length method returns the number of keys in the hash. This method
 return a number object.
 
 =head2 list
 
-    # given $hash
+  # given $hash
 
-    my $list = $hash->list;
+  my $list = $hash->list;
 
 The list method returns a shallow copy of the underlying hash reference as an
 array reference. This method return an array object.
 
 =head2 lookup
 
-    # given {1..3,{4,{5,6,7,{8,9,10,11}}}}
+  # given {1..3,{4,{5,6,7,{8,9,10,11}}}}
 
-    $hash->lookup('3.4.7'); # {8=>9,10=>11}
-    $hash->lookup('3.4'); # {5=>6,7=>{8=>9,10=>11}}
-    $hash->lookup(1); # 2
+  $hash->lookup('3.4.7'); # {8=>9,10=>11}
+  $hash->lookup('3.4'); # {5=>6,7=>{8=>9,10=>11}}
+  $hash->lookup(1); # 2
 
 The lookup method returns the value of the element in the hash whose key
 corresponds to the key specified in the argument. The key can be a string which
@@ -924,20 +913,20 @@ execution.
 
 =head2 lt
 
-    # given $hash
+  # given $hash
 
-    $hash->lt; # exception thrown
+  $hash->lt; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 map
 
-    # given {1..4}
+  # given {1..4}
 
-    $hash->map(sub {
-        shift + 1
-    });
+  $hash->map(sub {
+    shift + 1
+  });
 
 The map method iterates over each key/value in the hash, executing the code
 reference supplied in the argument, passing the routine the value at the
@@ -947,9 +936,9 @@ returns a L<Data::Object::Array> object.
 
 =head2 merge
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->merge({7,7,9,9}); # {1=>2,3=>4,5=>6,7=>7,9=>9}
+  $hash->merge({7,7,9,9}); # {1=>2,3=>4,5=>6,7=>7,9=>9}
 
 The merge method returns a hash reference where the elements in the hash and
 the elements in the argument(s) are merged. This operation performs a deep
@@ -960,37 +949,37 @@ object.
 
 =head2 methods
 
-    # given $hash
+  # given $hash
 
-    $hash->methods;
+  $hash->methods;
 
 The methods method returns the list of methods attached to object. This method
 returns an array value.
 
 =head2 ne
 
-    # given $hash
+  # given $hash
 
-    $hash->ne; # exception thrown
+  $hash->ne; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 new
 
-    # given 1..4
+  # given 1..4
 
-    my $hash = Data::Object::Hash->new(1..4);
-    my $hash = Data::Object::Hash->new({1..4});
+  my $hash = Data::Object::Hash->new(1..4);
+  my $hash = Data::Object::Hash->new({1..4});
 
 The new method expects a list or hash reference and returns a new class
 instance.
 
 =head2 pairs
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->pairs; # [[1,2],[3,4],[5,6],[7,8]]
+  $hash->pairs; # [[1,2],[3,4],[5,6],[7,8]]
 
 The pairs method is an alias to the pairs_array method. This method returns a
 array object. This method is an alias to the pairs_array
@@ -998,18 +987,18 @@ method.
 
 =head2 print
 
-    # given {1..4}
+  # given {1..4}
 
-    $hash->print; # '{1=>2,3=>4}'
+  $hash->print; # '{1=>2,3=>4}'
 
 The print method outputs the value represented by the object to STDOUT and
 returns true. This method returns a number value.
 
 =head2 reset
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->reset; # {1=>undef,3=>undef,5=>undef,7=>undef}
+  $hash->reset; # {1=>undef,3=>undef,5=>undef,7=>undef}
 
 The reset method returns nullifies the value of each element in the hash. This
 method returns a hash value. Note: This method modifies the
@@ -1017,9 +1006,9 @@ hash.
 
 =head2 reverse
 
-    # given {1..8,9,undef}
+  # given {1..8,9,undef}
 
-    $hash->reverse; # {8=>7,6=>5,4=>3,2=>1}
+  $hash->reverse; # {8=>7,6=>5,4=>3,2=>1}
 
 The reverse method returns a hash reference consisting of the hash's keys and
 values inverted. Note, keys with undefined values will be dropped. This method
@@ -1027,18 +1016,18 @@ returns a hash value.
 
 =head2 roles
 
-    # given $hash
+  # given $hash
 
-    $hash->roles;
+  $hash->roles;
 
 The roles method returns the list of roles attached to object. This method
 returns an array value.
 
 =head2 say
 
-    # given {1..4}
+  # given {1..4}
 
-    $hash->say; # '{1=>2,3=>4}\n'
+  $hash->say; # '{1=>2,3=>4}\n'
 
 The say method outputs the value represented by the object appended with a
 newline to STDOUT and returns true. This method returns a L<Data::Object::Number>
@@ -1046,11 +1035,11 @@ object.
 
 =head2 set
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->set(1,10); # 10
-    $hash->set(1,12); # 12
-    $hash->set(1,0); # 0
+  $hash->set(1,10); # 10
+  $hash->set(1,12); # 12
+  $hash->set(1,0); # 0
 
 The set method returns the value of the element in the hash corresponding to
 the key specified by the argument after updating it to the value of the second
@@ -1059,9 +1048,9 @@ execution.
 
 =head2 slice
 
-    # given {1..8}
+  # given {1..8}
 
-    my $slice = $hash->slice(1,5); # {1=>2,5=>6}
+  my $slice = $hash->slice(1,5); # {1=>2,5=>6}
 
 The slice method returns a hash reference containing the elements in the hash
 at the key(s) specified in the arguments. This method returns a
@@ -1069,27 +1058,27 @@ hash object.
 
 =head2 sort
 
-    # given $hash
+  # given $hash
 
-    $hash->sort; # exception thrown
+  $hash->sort; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 tail
 
-    # given $hash
+  # given $hash
 
-    $hash->tail; # exception thrown
+  $hash->tail; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 throw
 
-    # given $hash
+  # given $hash
 
-    $hash->throw;
+  $hash->throw;
 
 The throw method terminates the program using the core die keyword, passing the
 object to the L<Data::Object::Exception> class as the named parameter C<object>.
@@ -1097,18 +1086,18 @@ If captured this method returns an exception value.
 
 =head2 type
 
-    # given $hash
+  # given $hash
 
-    $hash->type; # HASH
+  $hash->type; # HASH
 
 The type method returns a string representing the internal data type object name.
 This method returns a string value.
 
 =head2 unfold
 
-    # given {'3:0'=>4,'3:1'=>5,'3:2'=>6,'7.8'=>8,'7.9'=>9}
+  # given {'3:0'=>4,'3:1'=>5,'3:2'=>6,'7.8'=>8,'7.9'=>9}
 
-    $hash->unfold; # {3=>[4,5,6],7,{8,8,9,9}}
+  $hash->unfold; # {3=>[4,5,6],7,{8,8,9,9}}
 
 The unfold method processes previously folded hash references and returns an
 unfolded hash reference where the keys, which are paths (using dot-notation
@@ -1118,10 +1107,10 @@ hash object.
 
 =head2 values
 
-    # given {1..8}
+  # given {1..8}
 
-    $hash->values; # [2,4,6,8]
-    $hash->values(1,3); # [2,4]
+  $hash->values; # [2,4,6,8]
+  $hash->values(1,3); # [2,4]
 
 The values method returns an array reference consisting of the values of the
 elements in the hash. This method returns an array value.
@@ -1266,7 +1255,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Al Newkirk.
+This software is copyright (c) 2018 by Al Newkirk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
