@@ -13,220 +13,221 @@ use Data::Object::Signatures;
 use Scalar::Util;
 
 map with($_), our @ROLES = qw(
-    Data::Object::Role::Item
-    Data::Object::Role::Alphabetic
-    Data::Object::Role::Value
+  Data::Object::Role::Item
+  Data::Object::Role::Alphabetic
+  Data::Object::Role::Value
 );
 
-our $VERSION = '0.59'; # VERSION
+our $VERSION = '0.60'; # VERSION
 
 method append (@args) {
 
-    return CORE::join(' ', "$self", @args);
+  return CORE::join(' ', "$self", @args);
 
 }
 
 method camelcase () {
 
-    my $result = CORE::ucfirst(CORE::lc("$self"));
+  my $result = CORE::ucfirst(CORE::lc("$self"));
 
-    $result =~ s/[^a-zA-Z0-9]+([a-z])/\U$1/g;
-    $result =~ s/[^a-zA-Z0-9]+//g;
+  $result =~ s/[^a-zA-Z0-9]+([a-z])/\U$1/g;
+  $result =~ s/[^a-zA-Z0-9]+//g;
 
-    return $result;
+  return $result;
 
 }
 
 method chomp () {
 
-    my $result = "$self";
+  my $result = "$self";
 
-    CORE::chomp($result);
+  CORE::chomp($result);
 
-    return $result;
+  return $result;
 
 }
 
 method chop () {
 
-    my $result = "$self";
+  my $result = "$self";
 
-    CORE::chop($result);
+  CORE::chop($result);
 
-    return $result;
+  return $result;
 
 }
 
 method concat (@args) {
 
-    return CORE::join('', "$self", @args);
+  return CORE::join('', "$self", @args);
 
 }
 
 method contains ($pattern) {
 
-    return 0 unless CORE::defined($pattern);
+  return 0 unless CORE::defined($pattern);
 
-    my $regexp = UNIVERSAL::isa($pattern, 'Regexp');
+  my $regexp = UNIVERSAL::isa($pattern, 'Regexp');
 
-    return CORE::index("$self", $pattern) < 0 ? 0 : 1 if ! $regexp;
+  return CORE::index("$self", $pattern) < 0 ? 0 : 1 if !$regexp;
 
-    return ("$self" =~ $pattern) ? 1 : 0;
+  return ("$self" =~ $pattern) ? 1 : 0;
 
 }
 
 method defined () {
 
-    return 1;
+  return 1;
 
 }
 
 method hex () {
 
-    return CORE::hex("$self");
+  return CORE::hex("$self");
 
 }
 
 method index ($substr, $start) {
 
-    return CORE::index("$self", $substr) if not CORE::defined $start;
+  return CORE::index("$self", $substr) if not CORE::defined $start;
 
-    return CORE::index("$self", $substr, $start);
+  return CORE::index("$self", $substr, $start);
 
 }
 
 method lc () {
 
-    return CORE::lc("$self");
+  return CORE::lc("$self");
 
 }
 
 method lcfirst () {
 
-    return CORE::lcfirst("$self");
+  return CORE::lcfirst("$self");
 
 }
 
 method length () {
 
-    return CORE::length("$self");
+  return CORE::length("$self");
 
 }
 
 method lines () {
 
-    return [CORE::split(/[\n\r]+/, "$self")];
+  return [CORE::split(/[\n\r]+/, "$self")];
 
 }
 
 method lowercase () {
 
-    return $self->lc;
+  return $self->lc;
 
 }
 
 method replace ($search, $replace, $flags) {
 
-    my $result = "$self";
-    my $regexp = UNIVERSAL::isa($search, 'Regexp');
+  my $result = "$self";
+  my $regexp = UNIVERSAL::isa($search, 'Regexp');
 
-    $flags  = CORE::defined($flags) ? $flags : '';
-    $search = CORE::quotemeta($search) if $search and ! $regexp;
+  $flags = CORE::defined($flags) ? $flags : '';
+  $search = CORE::quotemeta($search) if $search and !$regexp;
 
-    local $@; eval("sub { \$_[0] =~ s/$search/$replace/$flags }")->($result);
+  local $@;
+  eval("sub { \$_[0] =~ s/$search/$replace/$flags }")->($result);
 
-    return $result;
+  return $result;
 
 }
 
 method reverse () {
 
-    return CORE::reverse("$self");
+  return CORE::reverse("$self");
 
 }
 
 method rindex ($substr, $start) {
 
-    return CORE::rindex("$self", $substr) if not CORE::defined $start;
+  return CORE::rindex("$self", $substr) if not CORE::defined $start;
 
-    return CORE::rindex("$self", $substr, $start);
+  return CORE::rindex("$self", $substr, $start);
 
 }
 
 method snakecase () {
 
-    my $result = CORE::lc("$self");
+  my $result = CORE::lc("$self");
 
-    $result =~ s/[^a-zA-Z0-9]+([a-z])/\U$1/g;
-    $result =~ s/[^a-zA-Z0-9]+//g;
+  $result =~ s/[^a-zA-Z0-9]+([a-z])/\U$1/g;
+  $result =~ s/[^a-zA-Z0-9]+//g;
 
-    return $result;
+  return $result;
 
 }
 
 method split ($pattern, $limit) {
 
-    my $regexp = UNIVERSAL::isa($pattern, 'Regexp');
+  my $regexp = UNIVERSAL::isa($pattern, 'Regexp');
 
-    $pattern = CORE::quotemeta($pattern) if $pattern and ! $regexp;
+  $pattern = CORE::quotemeta($pattern) if $pattern and !$regexp;
 
-    return [CORE::split(/$pattern/, "$self")] if ! CORE::defined($limit);
+  return [CORE::split(/$pattern/, "$self")] if !CORE::defined($limit);
 
-    return [CORE::split(/$pattern/, "$self", $limit)];
+  return [CORE::split(/$pattern/, "$self", $limit)];
 
 }
 
 method strip () {
 
-    my $result = "$self";
+  my $result = "$self";
 
-    $result =~ s/\s{2,}/ /g;
+  $result =~ s/\s{2,}/ /g;
 
-    return $result;
+  return $result;
 
 }
 
 method titlecase () {
 
-    my $result = "$self";
+  my $result = "$self";
 
-    $result =~ s/\b(\w)/\U$1/g;
+  $result =~ s/\b(\w)/\U$1/g;
 
-    return $result;
+  return $result;
 
 }
 
 method trim () {
 
-    my $result = "$self";
+  my $result = "$self";
 
-    $result =~ s/^\s+|\s+$//g;
+  $result =~ s/^\s+|\s+$//g;
 
-    return $result;
+  return $result;
 
 }
 
 method uc () {
 
-    return CORE::uc("$self");
+  return CORE::uc("$self");
 
 }
 
 method ucfirst () {
 
-    return CORE::ucfirst("$self");
+  return CORE::ucfirst("$self");
 
 }
 
 method uppercase () {
 
-    return $self->uc;
+  return $self->uc;
 
 }
 
 method words () {
 
-    return [ CORE::split(/\s+/, "$self") ];
+  return [CORE::split(/\s+/, "$self")];
 
 }
 
@@ -244,13 +245,13 @@ Data::Object::Role::String - String Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
-    use Data::Object::Class;
+  use Data::Object::Class;
 
-    with 'Data::Object::Role::String';
+  with 'Data::Object::Role::String';
 
 =head1 DESCRIPTION
 
@@ -261,9 +262,9 @@ data.
 
 =head2 append
 
-    # given 'firstname'
+  # given 'firstname'
 
-    $string->append('lastname'); # firstname lastname
+  $string->append('lastname'); # firstname lastname
 
 The append method modifies and returns the string with the argument list
 appended to it separated using spaces. This method returns a
@@ -271,9 +272,9 @@ string object.
 
 =head2 camelcase
 
-    # given 'hello world'
+  # given 'hello world'
 
-    $string->camelcase; # HelloWorld
+  $string->camelcase; # HelloWorld
 
 The camelcase method modifies the string such that it will no longer have any
 non-alphanumeric characters and each word (group of alphanumeric characters
@@ -283,9 +284,9 @@ object.
 
 =head2 chomp
 
-    # given "name, age, dob, email\n"
+  # given "name, age, dob, email\n"
 
-    $string->chomp; # name, age, dob, email
+  $string->chomp; # name, age, dob, email
 
 The chomp method is a safer version of the chop method, it's used to remove the
 newline (or the current value of $/) from the end of the string. Note, this
@@ -294,9 +295,9 @@ string object.
 
 =head2 chop
 
-    # given "this is just a test."
+  # given "this is just a test."
 
-    $string->chop; # this is just a test
+  $string->chop; # this is just a test
 
 The chop method removes the last character of a string and returns the character
 chopped. It is much more efficient than "s/.$//s" because it neither scans nor
@@ -305,22 +306,22 @@ method returns a string value.
 
 =head2 concat
 
-    # given 'ABC'
+  # given 'ABC'
 
-    $string->concat('DEF', 'GHI'); # ABCDEFGHI
+  $string->concat('DEF', 'GHI'); # ABCDEFGHI
 
 The concat method modifies and returns the string with the argument list
 appended to it. This method returns a string value.
 
 =head2 contains
 
-    # given 'Nullam ultrices placerat nibh vel malesuada.'
+  # given 'Nullam ultrices placerat nibh vel malesuada.'
 
-    $string->contains('trices'); # 1; true
-    $string->contains('itrices'); # 0; false
+  $string->contains('trices'); # 1; true
+  $string->contains('itrices'); # 0; false
 
-    $string->contains(qr/trices/); # 1; true
-    $string->contains(qr/itrices/); # 0; false
+  $string->contains(qr/trices/); # 1; true
+  $string->contains(qr/itrices/); # 0; false
 
 The contains method searches the string for the string specified in the
 argument and returns true if found, otherwise returns false. If the argument is
@@ -331,18 +332,18 @@ object.
 
 =head2 data
 
-    # given $string
+  # given $string
 
-    $string->data; # original value
+  $string->data; # original value
 
 The data method returns the original and underlying value contained by the
 object. This method is an alias to the detract method.
 
 =head2 defined
 
-    # given $string
+  # given $string
 
-    $string->defined; # 1
+  $string->defined; # 1
 
 The defined method returns true if the object represents a value that meets the
 criteria for being defined, otherwise it returns false. This method returns a
@@ -350,36 +351,36 @@ number object.
 
 =head2 detract
 
-    # given $string
+  # given $string
 
-    $string->detract; # original value
+  $string->detract; # original value
 
 The detract method returns the original and underlying value contained by the
 object.
 
 =head2 dump
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->dump; # 'exciting'
+  $string->dump; # 'exciting'
 
 The dump method returns returns a string representation of the object.
 This method returns a string value.
 
 =head2 eq
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->eq('Exciting'); # 0
+  $string->eq('Exciting'); # 0
 
 The eq method returns true if the argument provided is equal to the value
 represented by the object. This method returns a number value.
 
 =head2 ge
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->ge('Exciting'); # 1
+  $string->ge('Exciting'); # 1
 
 The ge method returns true if the argument provided is greater-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
@@ -387,18 +388,18 @@ object.
 
 =head2 gt
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->gt('Exciting'); # 1
+  $string->gt('Exciting'); # 1
 
 The gt method returns true if the argument provided is greater-than the value
 represented by the object. This method returns a number value.
 
 =head2 hex
 
-    # given '0xaf'
+  # given '0xaf'
 
-    string->hex; # 175
+  string->hex; # 175
 
 The hex method returns the value resulting from interpreting the string as a
 hex string. This method returns a data type object to be determined after
@@ -406,14 +407,14 @@ execution.
 
 =head2 index
 
-    # given 'unexplainable'
+  # given 'unexplainable'
 
-    $string->index('explain'); # 2
-    $string->index('explain', 0); # 2
-    $string->index('explain', 1); # 2
-    $string->index('explain', 2); # 2
-    $string->index('explain', 3); # -1
-    $string->index('explained'); # -1
+  $string->index('explain'); # 2
+  $string->index('explain', 0); # 2
+  $string->index('explain', 1); # 2
+  $string->index('explain', 2); # 2
+  $string->index('explain', 3); # -1
+  $string->index('explained'); # -1
 
 The index method searches for the argument within the string and returns the
 position of the first occurrence of the argument. This method optionally takes a
@@ -424,27 +425,27 @@ after execution.
 
 =head2 lc
 
-    # given 'EXCITING'
+  # given 'EXCITING'
 
-    $string->lc; # exciting
+  $string->lc; # exciting
 
 The lc method returns a lowercased version of the string. This method returns a
 string object. This method is an alias to the lowercase method.
 
 =head2 lcfirst
 
-    # given 'EXCITING'
+  # given 'EXCITING'
 
-    $string->lcfirst; # eXCITING
+  $string->lcfirst; # eXCITING
 
 The lcfirst method returns a the string with the first character lowercased.
 This method returns a string value.
 
 =head2 le
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->le('Exciting'); # 0
+  $string->le('Exciting'); # 0
 
 The le method returns true if the argument provided is less-than or equal-to
 the value represented by the object. This method returns a Data::Object::Number
@@ -452,18 +453,18 @@ object.
 
 =head2 length
 
-    # given 'longggggg'
+  # given 'longggggg'
 
-    $string->length; # 9
+  $string->length; # 9
 
 The length method returns the number of characters within the string. This
 method returns a number value.
 
 =head2 lines
 
-    # given "who am i?\nwhere am i?\nhow did I get here"
+  # given "who am i?\nwhere am i?\nhow did I get here"
 
-    $string->lines; # ['who am i?','where am i?','how did i get here']
+  $string->lines; # ['who am i?','where am i?','how did i get here']
 
 The lines method breaks the string into pieces, split on 1 or more newline
 characters, and returns an array reference consisting of the pieces. This method
@@ -471,65 +472,65 @@ returns an array value.
 
 =head2 lowercase
 
-    # given 'EXCITING'
+  # given 'EXCITING'
 
-    $string->lowercase; # exciting
+  $string->lowercase; # exciting
 
 The lowercase method is an alias to the lc method. This method returns a
 string object.
 
 =head2 lt
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->lt('Exciting'); # 0
+  $string->lt('Exciting'); # 0
 
 The lt method returns true if the argument provided is less-than the value
 represented by the object. This method returns a number value.
 
 =head2 methods
 
-    # given $string
+  # given $string
 
-    $string->methods;
+  $string->methods;
 
 The methods method returns the list of methods attached to object. This method
 returns an array value.
 
 =head2 ne
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->ne('Exciting'); # 1
+  $string->ne('Exciting'); # 1
 
 The ne method returns true if the argument provided is not equal to the value
 represented by the object. This method returns a number value.
 
 =head2 new
 
-    # given abcedfghi
+  # given abcedfghi
 
-    my $string = Data::Object::String->new('abcedfghi');
+  my $string = Data::Object::String->new('abcedfghi');
 
 The new method expects a string and returns a new class instance.
 
 =head2 print
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->print; # 'exciting'
+  $string->print; # 'exciting'
 
 The print method outputs the value represented by the object to STDOUT and
 returns true. This method returns a number value.
 
 =head2 replace
 
-    # given 'Hello World'
+  # given 'Hello World'
 
-    $string->replace('World', 'Universe'); # Hello Universe
-    $string->replace('world', 'Universe', 'i'); # Hello Universe
-    $string->replace(qr/world/i, 'Universe'); # Hello Universe
-    $string->replace(qr/.*/, 'Nada'); # Nada
+  $string->replace('World', 'Universe'); # Hello Universe
+  $string->replace('world', 'Universe', 'i'); # Hello Universe
+  $string->replace(qr/world/i, 'Universe'); # Hello Universe
+  $string->replace(qr/.*/, 'Nada'); # Nada
 
 The replace method performs a smart search and replace operation and returns the
 modified string (if any modification occurred). This method optionally takes a
@@ -539,27 +540,27 @@ string object.
 
 =head2 reverse
 
-    # given 'dlrow ,olleH'
+  # given 'dlrow ,olleH'
 
-    $string->reverse; # Hello, world
+  $string->reverse; # Hello, world
 
 The reverse method returns a string where the characters in the string are in
 the opposite order. This method returns a string value.
 
 =head2 rindex
 
-    # given 'explain the unexplainable'
+  # given 'explain the unexplainable'
 
-    $string->rindex('explain'); # 14
-    $string->rindex('explain', 0); # 0
-    $string->rindex('explain', 21); # 14
-    $string->rindex('explain', 22); # 14
-    $string->rindex('explain', 23); # 14
-    $string->rindex('explain', 20); # 14
-    $string->rindex('explain', 14); # 0
-    $string->rindex('explain', 13); # 0
-    $string->rindex('explain', 0); # 0
-    $string->rindex('explained'); # -1
+  $string->rindex('explain'); # 14
+  $string->rindex('explain', 0); # 0
+  $string->rindex('explain', 21); # 14
+  $string->rindex('explain', 22); # 14
+  $string->rindex('explain', 23); # 14
+  $string->rindex('explain', 20); # 14
+  $string->rindex('explain', 14); # 0
+  $string->rindex('explain', 13); # 0
+  $string->rindex('explain', 0); # 0
+  $string->rindex('explained'); # -1
 
 The rindex method searches for the argument within the string and returns the
 position of the last occurrence of the argument. This method optionally takes a
@@ -570,18 +571,18 @@ be determined after execution.
 
 =head2 roles
 
-    # given $string
+  # given $string
 
-    $string->roles;
+  $string->roles;
 
 The roles method returns the list of roles attached to object. This method
 returns an array value.
 
 =head2 say
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->say; # 'exciting\n'
+  $string->say; # 'exciting\n'
 
 The say method outputs the value represented by the object appended with a
 newline to STDOUT and returns true. This method returns a L<Data::Object::Number>
@@ -589,9 +590,9 @@ object.
 
 =head2 snakecase
 
-    # given 'hello world'
+  # given 'hello world'
 
-    $string->snakecase; # helloWorld
+  $string->snakecase; # helloWorld
 
 The snakecase method modifies the string such that it will no longer have any
 non-alphanumeric characters and each word (group of alphanumeric characters
@@ -602,12 +603,12 @@ modifies the string. This method returns a string value.
 
 =head2 split
 
-    # given 'name, age, dob, email'
+  # given 'name, age, dob, email'
 
-    $string->split(', '); # ['name', 'age', 'dob', 'email']
-    $string->split(', ', 2); # ['name', 'age, dob, email']
-    $string->split(qr/\,\s*/); # ['name', 'age', 'dob', 'email']
-    $string->split(qr/\,\s*/, 2); # ['name', 'age, dob, email']
+  $string->split(', '); # ['name', 'age', 'dob', 'email']
+  $string->split(', ', 2); # ['name', 'age, dob, email']
+  $string->split(qr/\,\s*/); # ['name', 'age', 'dob', 'email']
+  $string->split(qr/\,\s*/, 2); # ['name', 'age, dob, email']
 
 The split method splits the string into a list of strings, separating each
 chunk by the argument (string or regexp object), and returns that list as an
@@ -618,9 +619,9 @@ array object.
 
 =head2 strip
 
-    # given 'one,  two,  three'
+  # given 'one,  two,  three'
 
-    $string->strip; # one, two, three
+  $string->strip; # one, two, three
 
 The strip method returns the string replacing occurences of 2 or more
 whitespaces with a single whitespace. This method returns a
@@ -628,9 +629,9 @@ string object.
 
 =head2 throw
 
-    # given $string
+  # given $string
 
-    $string->throw;
+  $string->throw;
 
 The throw method terminates the program using the core die keyword, passing the
 object to the L<Data::Object::Exception> class as the named parameter C<object>.
@@ -638,9 +639,9 @@ If captured this method returns an exception value.
 
 =head2 titlecase
 
-    # given 'mr. john doe'
+  # given 'mr. john doe'
 
-    $string->titlecase; # Mr. John Doe
+  $string->titlecase; # Mr. John Doe
 
 The titlecase method returns the string capitalizing the first character of
 each word (group of alphanumeric characters separated by 1 or more whitespaces).
@@ -649,54 +650,54 @@ string object.
 
 =head2 trim
 
-    # given ' system is   ready   '
+  # given ' system is   ready   '
 
-    $string->trim; # system is   ready
+  $string->trim; # system is   ready
 
 The trim method removes 1 or more consecutive leading and/or trailing spaces
 from the string. This method returns a string value.
 
 =head2 type
 
-    # given $string
+  # given $string
 
-    $string->type; # STRING
+  $string->type; # STRING
 
 The type method returns a string representing the internal data type object name.
 This method returns a string value.
 
 =head2 uc
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->uc; # EXCITING
+  $string->uc; # EXCITING
 
 The uc method returns an uppercased version of the string. This method returns a
 string object. This method is an alias to the uppercase method.
 
 =head2 ucfirst
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->ucfirst; # Exciting
+  $string->ucfirst; # Exciting
 
 The ucfirst method returns a the string with the first character uppercased.
 This method returns a string value.
 
 =head2 uppercase
 
-    # given 'exciting'
+  # given 'exciting'
 
-    $string->uppercase; # EXCITING
+  $string->uppercase; # EXCITING
 
 The uppercase method is an alias to the uc method. This method returns a
 string object.
 
 =head2 words
 
-    # given "is this a bug we're experiencing"
+  # given "is this a bug we're experiencing"
 
-    $string->words; # ["is","this","a","bug","we're","experiencing"]
+  $string->words; # ["is","this","a","bug","we're","experiencing"]
 
 The words method splits the string into a list of strings, separating each
 group of characters by 1 or more consecutive spaces, and returns that list as an
@@ -842,7 +843,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Al Newkirk.
+This software is copyright (c) 2018 by Al Newkirk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
