@@ -13,63 +13,63 @@ use Data::Object::Signatures;
 use Scalar::Util;
 
 map with($_), our @ROLES = qw(
-    Data::Object::Role::Item
-    Data::Object::Role::Value
+  Data::Object::Role::Item
+  Data::Object::Role::Value
 );
 
-our $VERSION = '0.59'; # VERSION
+our $VERSION = '0.60'; # VERSION
 
 method defined () {
 
-    return 1;
+  return 1;
 
 }
 
-method eq {
+method eq () {
 
-    $self->throw("The eq() comparison operation is not supported");
+  $self->throw("The eq() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
-method gt {
+method gt () {
 
-    $self->throw("The gt() comparison operation is not supported");
+  $self->throw("The gt() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
-method ge {
+method ge () {
 
-    $self->throw("The ge() comparison operation is not supported");
+  $self->throw("The ge() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
-method lt {
+method lt () {
 
-    $self->throw("The lt() comparison operation is not supported");
+  $self->throw("The lt() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
-method le {
+method le () {
 
-    $self->throw("The le() comparison operation is not supported");
+  $self->throw("The le() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
-method ne {
+method ne () {
 
-    $self->throw("The ne() comparison operation is not supported");
+  $self->throw("The ne() comparison operation is not supported");
 
-    return;
+  return;
 
 }
 
@@ -87,13 +87,13 @@ Data::Object::Role::Universal - Universal Object Role for Perl 5
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
-    use Data::Object::Class;
+  use Data::Object::Class;
 
-    with 'Data::Object::Role::Universal';
+  with 'Data::Object::Role::Universal';
 
 =head1 DESCRIPTION
 
@@ -104,18 +104,18 @@ data type.
 
 =head2 data
 
-    # given $object
+  # given $object
 
-    $object->data; # original value
+  $object->data; # original value
 
 The data method returns the original and underlying value contained by the
 object. This method is an alias to the detract method.
 
 =head2 defined
 
-    # given $object
+  # given $object
 
-    $object->defined; # 1
+  $object->defined; # 1
 
 The defined method returns true if the object represents a value that meets the
 criteria for being defined, otherwise it returns false. This method returns a
@@ -123,116 +123,116 @@ number object.
 
 =head2 detract
 
-    # given $object
+  # given $object
 
-    $object->detract; # original value
+  $object->detract; # original value
 
 The detract method returns the original and underlying value contained by the
 object.
 
 =head2 dump
 
-    # given 0
+  # given 0
 
-    $object->dump; # 0
+  $object->dump; # 0
 
 The dump method returns returns a string representation of the object.
 This method returns a string value.
 
 =head2 eq
 
-    # given $object
+  # given $object
 
-    $object->eq; # exception thrown
+  $object->eq; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 ge
 
-    # given $object
+  # given $object
 
-    $object->ge; # exception thrown
+  $object->ge; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 gt
 
-    # given $object
+  # given $object
 
-    $object->gt; # exception thrown
+  $object->gt; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 le
 
-    # given $object
+  # given $object
 
-    $object->le; # exception thrown
+  $object->le; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 lt
 
-    # given $object
+  # given $object
 
-    $object->lt; # exception thrown
+  $object->lt; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 methods
 
-    # given $object
+  # given $object
 
-    $object->methods;
+  $object->methods;
 
 The methods method returns the list of methods attached to object. This method
 returns an array value.
 
 =head2 ne
 
-    # given $object
+  # given $object
 
-    $object->ne; # exception thrown
+  $object->ne; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 new
 
-    # given $scalar
+  # given $scalar
 
-    my $object = Data::Object::Universal->new($scalar);
+  my $object = Data::Object::Universal->new($scalar);
 
 The new method expects a scalar reference and returns a new class instance.
 
 =head2 print
 
-    # given 0
+  # given 0
 
-    $object->print; # 0
+  $object->print; # 0
 
 The print method outputs the value represented by the object to STDOUT and
 returns true. This method returns a number value.
 
 =head2 roles
 
-    # given $object
+  # given $object
 
-    $object->roles;
+  $object->roles;
 
 The roles method returns the list of roles attached to object. This method
 returns an array value.
 
 =head2 say
 
-    # given 0
+  # given 0
 
-    $object->say; # '0\n'
+  $object->say; # '0\n'
 
 The say method outputs the value represented by the object appended with a
 newline to STDOUT and returns true. This method returns a L<Data::Object::Number>
@@ -240,9 +240,9 @@ object.
 
 =head2 throw
 
-    # given $object
+  # given $object
 
-    $object->throw;
+  $object->throw;
 
 The throw method terminates the program using the core die keyword, passing the
 object to the L<Data::Object::Exception> class as the named parameter C<object>.
@@ -250,9 +250,9 @@ If captured this method returns an exception value.
 
 =head2 type
 
-    # given $object
+  # given $object
 
-    $object->type; # UNIVERSAL
+  $object->type; # UNIVERSAL
 
 The type method returns a string representing the internal data type object name.
 This method returns a string value.
@@ -393,7 +393,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Al Newkirk.
+This software is copyright (c) 2018 by Al Newkirk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
