@@ -14,33 +14,34 @@ use Scalar::Util;
 
 with 'Data::Object::Role::Undef';
 
-our $VERSION = '0.59'; # VERSION
+our $VERSION = '0.60'; # VERSION
 
 method new ($class: @args) {
 
-    my $arg  = $args[0];
-    my $role = 'Data::Object::Role::Type';
+  my $arg  = $args[0];
+  my $role = 'Data::Object::Role::Type';
 
-    $arg = $arg->data if Scalar::Util::blessed($arg)
-        and $arg->can('does')
-        and $arg->does($role);
+  $arg = $arg->data
+    if Scalar::Util::blessed($arg)
+    and $arg->can('does')
+    and $arg->does($role);
 
-    Data::Object::throw('Type Instantiation Error: Not an Undefined value')
-        if defined $arg;
+  Data::Object::throw('Type Instantiation Error: Not an Undefined value')
+    if defined $arg;
 
-    return bless \$arg, $class;
+  return bless \$arg, $class;
 
 }
 
-our @METHODS = @{ __PACKAGE__->methods };
+our @METHODS = @{__PACKAGE__->methods};
 
-my  $exclude = qr/^data|detract|new$/;
+my $exclude = qr/^data|detract|new$/;
 
-around [ grep { !/$exclude/ } @METHODS ] => fun ($orig, $self, @args) {
+around [grep { !/$exclude/ } @METHODS] => fun($orig, $self, @args) {
 
-    my $results = $self->$orig(@args);
+  my $results = $self->$orig(@args);
 
-    return Data::Object::deduce_deep($results);
+  return Data::Object::deduce_deep($results);
 
 };
 
@@ -58,13 +59,13 @@ Data::Object::Undef - Undef Object for Perl 5
 
 =head1 VERSION
 
-version 0.59
+version 0.60
 
 =head1 SYNOPSIS
 
-    use Data::Object::Undef;
+  use Data::Object::Undef;
 
-    my $undef = Data::Object::Undef->new(undef);
+  my $undef = Data::Object::Undef->new(undef);
 
 =head1 DESCRIPTION
 
@@ -80,134 +81,134 @@ role and implements proxy methods as documented herewith.
 
 =head2 data
 
-    # given $undef
+  # given $undef
 
-    $undef->data; # original value
+  $undef->data; # original value
 
 The data method returns the original and underlying value contained by the
 object. This method is an alias to the detract method.
 
 =head2 defined
 
-    # given undef
+  # given undef
 
-    $undef->defined ? 'Yes' : 'No'; # No
+  $undef->defined ? 'Yes' : 'No'; # No
 
 The defined method always returns false. This method returns a
 L<Data::Object::Number> object.
 
 =head2 detract
 
-    # given $undef
+  # given $undef
 
-    $undef->detract; # original value
+  $undef->detract; # original value
 
 The detract method returns the original and underlying value contained by the
 object.
 
 =head2 dump
 
-    # given $undef
+  # given $undef
 
-    $undef->dump; # 'undef'
+  $undef->dump; # 'undef'
 
 The dump method returns returns a string representation of the object.
 This method returns a L<Data::Object::String> object.
 
 =head2 eq
 
-    # given $undef
+  # given $undef
 
-    $undef->eq; # exception thrown
+  $undef->eq; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 ge
 
-    # given $undef
+  # given $undef
 
-    $undef->ge; # exception thrown
+  $undef->ge; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 gt
 
-    # given $undef
+  # given $undef
 
-    $undef->gt; # exception thrown
+  $undef->gt; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 le
 
-    # given $undef
+  # given $undef
 
-    $undef->le; # exception thrown
+  $undef->le; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 lt
 
-    # given $undef
+  # given $undef
 
-    $undef->lt; # exception thrown
+  $undef->lt; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 methods
 
-    # given $undef
+  # given $undef
 
-    $undef->methods;
+  $undef->methods;
 
 The methods method returns the list of methods attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 ne
 
-    # given $undef
+  # given $undef
 
-    $undef->ne; # exception thrown
+  $undef->ne; # exception thrown
 
 This method is a consumer requirement but has no function and is not implemented.
 This method will throw an exception if called.
 
 =head2 new
 
-    # given undef
+  # given undef
 
-    my $undef = Data::Object::Undef->new(undef);
+  my $undef = Data::Object::Undef->new(undef);
 
 The new method expects an undefined value and returns a new class instance.
 
 =head2 print
 
-    # given $undef
+  # given $undef
 
-    $undef->print; # 'undef'
+  $undef->print; # 'undef'
 
 The print method outputs the value represented by the object to STDOUT and
 returns true. This method returns a L<Data::Object::Number> object.
 
 =head2 roles
 
-    # given $undef
+  # given $undef
 
-    $undef->roles;
+  $undef->roles;
 
 The roles method returns the list of roles attached to object. This method
 returns a L<Data::Object::Array> object.
 
 =head2 say
 
-    # given $undef
+  # given $undef
 
-    $undef->say; # 'undef\n'
+  $undef->say; # 'undef\n'
 
 The say method outputs the value represented by the object appended with a
 newline to STDOUT and returns true. This method returns a L<Data::Object::Number>
@@ -215,9 +216,9 @@ object.
 
 =head2 throw
 
-    # given $undef
+  # given $undef
 
-    $undef->throw;
+  $undef->throw;
 
 The throw method terminates the program using the core die keyword, passing the
 object to the L<Data::Object::Exception> class as the named parameter C<object>.
@@ -225,9 +226,9 @@ If captured this method returns a L<Data::Object::Exception> object.
 
 =head2 type
 
-    # given $undef
+  # given $undef
 
-    $undef->type; # UNDEF
+  $undef->type; # UNDEF
 
 The type method returns a string representing the internal data type object name.
 This method returns a L<Data::Object::String> object.
@@ -368,7 +369,7 @@ Al Newkirk <anewkirk@ana.io>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by Al Newkirk.
+This software is copyright (c) 2018 by Al Newkirk.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
